@@ -5,13 +5,13 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-ce", "1.63.0", __name__[0:-6], "aws-ce@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-ce", "1.65.0", __name__[0:-6], "aws-ce@1.65.0.jsii.tgz"
 )
 
 __all__ = [
